pecos.simulators.sparsesim.refactor
===================================

.. automodule:: pecos.simulators.sparsesim.refactor







   .. rubric:: Functions

   .. autosummary::

      find_stab
      refactor
